* {
  box-sizing: border-box; }

a {
  color: #0064ff;
  text-decoration: none; }
  a:hover {
    text-decoration: underline; }

html, body {
  margin: 0;
  color: #333;
  opacity: 1;
  line-height: 1.5;
  font-size: 16px;
  font-family: Helvetica, Tahoma, sans-serif; }

h1, h2, h3, h4, h5, h6 {
  line-height: 1;
  margin: 30px 0 0 0;
  padding: 0;
  font-weight: 600; }

.header {
  max-width: 800px;
  margin: 0 auto;
  padding: 50px 50px 25px; }
  @media (max-width: 599px) {
    .header {
      padding: 25px 25px 25px; } }
  .header__primary-nav {
    display: flex;
    justify-content: space-between;
    align-items: center; }

.publish-button {
  background-color: #fff;
  border: 1px solid #333;
  color: #333;
  display: flex;
  margin: 0;
  padding: 7px 15px 3px;
  cursor: pointer;
  font: inherit;
  border-radius: 3px; }

pre {
  background: #f9f9f9;
  white-space: break-spaces;
  word-break: break-all;
  border-radius: 3px;
  padding: 20px;
  font-size: 14px; }

code {
  background: #f9f9f9;
  padding: 5px;
  border-radius: 3px;
  margin: 0 5px; }

main {
  line-height: 2;
  max-width: 65ch;
  padding: 0 50px;
  max-width: 800px;
  margin: 0 auto; }
  main > :first-child {
    margin-top: 0; }
  @media (max-width: 599px) {
    main {
      padding: 0 25px; } }

.children-nav {
  position: relative;
  margin: 25px 0 0;
  width: 100%;
  font-size: 16px; }
  .children-nav__title {
    cursor: pointer;
    font-weight: 600; }
    @media (max-width: 599px) {
      .children-nav__title--navigator {
        height: 55px;
        display: flex;
        align-items: center;
        border-radius: 3px;
        padding: 10px;
        width: 300px;
        border: 1px solid; } }
  .children-nav__list {
    margin: 0;
    padding: 0 30px;
    list-style: square; }
    .children-nav__list--visible {
      display: block; }
    .children-nav__list__item {
      margin: 10px 0; }
      .children-nav__list__item a {
        color: #0064ff;
        margin-left: 5px; }
  .children-nav__input {
    margin: 0;
    cursor: pointer;
    -webkit-appearance: none;
    position: absolute;
    width: 140px;
    height: 17px; }
    @media (max-width: 599px) {
      .children-nav__input {
        width: 300px;
        height: 55px; } }

h1 {
  font-size: 28px;
  font-weight: 600; }

h2 {
  font-size: 22px; }

h3 {
  font-size: 18px; }

h4 {
  font-size: 18px;
  color: #777; }

h5 {
  font-size: 16px; }

.logo {
  font-weight: 600;
  color: inherit;
  text-decoration: none; }

.publish-alert-banner {
  display: none;
  padding: 10px;
  margin: 0 0 20px;
  border-radius: 3px; }
  .publish-alert-banner__fail {
    background-color: #f54242;
    color: #fff;
    display: block; }
  .publish-alert-banner__success {
    background-color: #a8e4ff;
    display: block; }

.menu__list {
  padding: 0;
  margin: 0;
  list-style: none;
  display: flex;
  color: #0064ff; }
  .menu__list__item {
    margin-right: 5px; }
    .menu__list__item::after {
      font-weight: normal;
      content: '/';
      margin-left: 5px; }
    .menu__list__item--bold {
      font-weight: 600; }
    .menu__list__item:last-child::after {
      content: ''; }
    .menu__list__item a {
      color: inherit; }

li > p {
  margin: 0; }

ul {
  padding: 0 25px; }
  ul li {
    margin-top: 5px; }

p {
  max-width: 65ch; }
